@@ -48,112 +48,112 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="123"/>
+        <location filename="../mxbootrepair.ui" line="136"/>
         <location filename="../mxbootrepair.cpp" line="376"/>
         <source>Select Boot Method</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="141"/>
+        <location filename="../mxbootrepair.ui" line="154"/>
         <source>Master Boot Record</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="144"/>
+        <location filename="../mxbootrepair.ui" line="157"/>
         <source>MBR</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="147"/>
-        <location filename="../mxbootrepair.ui" line="417"/>
+        <location filename="../mxbootrepair.ui" line="160"/>
+        <location filename="../mxbootrepair.ui" line="430"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="169"/>
+        <location filename="../mxbootrepair.ui" line="182"/>
         <source>Root (Partition Boot Record)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="172"/>
+        <location filename="../mxbootrepair.ui" line="185"/>
         <location filename="../mxbootrepair.cpp" line="378"/>
         <source>root</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="223"/>
+        <location filename="../mxbootrepair.ui" line="236"/>
         <location filename="../mxbootrepair.cpp" line="377"/>
         <source>Install on:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="242"/>
+        <location filename="../mxbootrepair.ui" line="255"/>
         <source>Location:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="264"/>
+        <location filename="../mxbootrepair.ui" line="277"/>
         <source>Select /boot location:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="277"/>
+        <location filename="../mxbootrepair.ui" line="290"/>
         <source>EFI System Partition</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="280"/>
+        <location filename="../mxbootrepair.ui" line="293"/>
         <source>ESP</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="407"/>
+        <location filename="../mxbootrepair.ui" line="420"/>
         <source>About this application</source>
         <translation>Um þetta forrit</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="410"/>
+        <location filename="../mxbootrepair.ui" line="423"/>
         <source>About...</source>
         <translation>Um hugbúnaðinn...</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="459"/>
+        <location filename="../mxbootrepair.ui" line="472"/>
         <source>Display help </source>
         <translation>Birta hjálp</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="462"/>
+        <location filename="../mxbootrepair.ui" line="475"/>
         <source>Help</source>
         <translation>Hjálp</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="469"/>
+        <location filename="../mxbootrepair.ui" line="482"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="510"/>
+        <location filename="../mxbootrepair.ui" line="523"/>
         <source>Cancel any changes then quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="513"/>
+        <location filename="../mxbootrepair.ui" line="526"/>
         <location filename="../mxbootrepair.cpp" line="449"/>
         <source>Cancel</source>
         <translation>Hætta við</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="520"/>
+        <location filename="../mxbootrepair.ui" line="533"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="539"/>
+        <location filename="../mxbootrepair.ui" line="552"/>
         <source>Apply any changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.ui" line="542"/>
+        <location filename="../mxbootrepair.ui" line="555"/>
         <location filename="../mxbootrepair.cpp" line="76"/>
         <source>Apply</source>
         <translation>Virkja</translation>
@@ -223,14 +223,6 @@ Please double-check the selected location.</source>
 Are you sure?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Yes</source>
-        <translation type="vanished">Já</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation type="vanished">Nei</translation>
-    </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="245"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
@@ -314,6 +306,7 @@ Are you sure?</source>
     </message>
     <message>
         <location filename="../mxbootrepair.cpp" line="447"/>
+        <location filename="../mxbootrepair.cpp" line="460"/>
         <source>License</source>
         <translation>Notkunarleyfi</translation>
     </message>
@@ -323,9 +316,14 @@ Are you sure?</source>
         <translation>Breytingaskrá</translation>
     </message>
     <message>
-        <location filename="../mxbootrepair.cpp" line="470"/>
+        <location filename="../mxbootrepair.cpp" line="472"/>
         <source>&amp;Close</source>
         <translation>&amp;Loka</translation>
     </message>
+    <message>
+        <location filename="../mxbootrepair.cpp" line="497"/>
+        <source>MX Cleanup</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
